# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Vision and Language datasets."""

from tensorflow_datasets.vision_language.gref import Gref
from tensorflow_datasets.vision_language.grounded_scan import GroundedScan
from tensorflow_datasets.vision_language.laion400m import Laion400m
from tensorflow_datasets.vision_language.refcoco import RefCoco
from tensorflow_datasets.vision_language.wit import Wit
from tensorflow_datasets.vision_language.wit_kaggle import WitKaggle
